summaryrefslogtreecommitdiffstats
path: root/kmail/subscriptiondialog.h
diff options
context:
space:
mode:
Diffstat (limited to 'kmail/subscriptiondialog.h')
-rw-r--r--kmail/subscriptiondialog.h20
1 files changed, 11 insertions, 9 deletions
diff --git a/kmail/subscriptiondialog.h b/kmail/subscriptiondialog.h
index 1d5a0148..4d3a01db 100644
--- a/kmail/subscriptiondialog.h
+++ b/kmail/subscriptiondialog.h
@@ -19,11 +19,11 @@
In addition, as a special exception, the copyright holders give
permission to link the code of this program with any edition of
- the Qt library by Trolltech AS, Norway (or with modified versions
- of Qt that use the same license as Qt), and distribute linked
+ the TQt library by Trolltech AS, Norway (or with modified versions
+ of TQt that use the same license as TQt), and distribute linked
combinations including the two. You must obey the GNU General
Public License in all respects for all of the code used other than
- Qt. If you modify this file, you may extend this exception to
+ TQt. If you modify this file, you may extend this exception to
your version of the file, but you are not obligated to do so. If
you do not wish to do so, delete this exception statement from
your version.
@@ -47,22 +47,23 @@ namespace KMail {
class SubscriptionDialogBase : public KSubscription
{
Q_OBJECT
+ TQ_OBJECT
public:
- SubscriptionDialogBase( TQWidget *parent,
+ SubscriptionDialogBase( TQWidget *tqparent,
const TQString &caption,
KAccount* acct,
- TQString startPath = TQString::null );
+ TQString startPath = TQString() );
virtual ~SubscriptionDialogBase() {}
void show();
protected:
/**
* Find the parent item
*/
void findParentItem ( TQString &name, TQString &path, TQString &compare,
- GroupItem **parent, GroupItem **oldItem );
+ GroupItem **tqparent, GroupItem **oldItem );
/**
* Process the next prefix in mPrefixList
@@ -127,12 +128,13 @@ namespace KMail {
class SubscriptionDialog : public SubscriptionDialogBase
{
Q_OBJECT
+ TQ_OBJECT
public:
- SubscriptionDialog( TQWidget *parent,
+ SubscriptionDialog( TQWidget *tqparent,
const TQString &caption,
KAccount* acct,
- TQString startPath = TQString::null );
+ TQString startPath = TQString() );
virtual ~SubscriptionDialog();
protected:
/** reimpl */
@@ -47,22 +47,23 @@ namespace KMail {
protected:
/**
- * Find the parent item
+ * Find the tqparent item
*/
void findParentItem ( TQString &name, TQString &path, TQString &compare,